@@ -9,6 +9,17 @@ import gc
 import sklearn.metrics as mt
 
 
+class _Folds:
+    def __init__(self, folds):
+        self.indices = folds
+
+    def split(self, X=None, y=None, groups=None):
+        for i in range(len(self.indices)):
+            yield self.indices(i)
+
+    def get_n_splits(self):
+        return len(self.indices)
+
 # Class to hold and train many models (CB, XGB and LGB) on the same dataset
 class GBMFitter:
     def __init__(self, cb_data=[], xgb_data=[], lgb_data=[], cv_strategy=None, cv_groups=None, use_rounders=False, metrics=['rmse']):
@@ -27,11 +38,17 @@ class GBMFitter:
         self.rounders = {'CB': [], 'XGB': [], 'LGB': []}
         self.oof = {'CB': []}
         self.fselection = {}
-        self.cv = cv_strategy
+
         self.cv_groups = cv_groups
         self.use_rounders = use_rounders
         self.metrics = metrics
 
+        if isinstance(cv_strategy, list):
+            self.cv = _Folds(list)
+        else:
+            self.cv = cv_strategy
+
+
     def _get_categorical_index(self, df, cat_cols):
         cat_features_index = np.where(df.columns.isin(cat_cols))[0].tolist()
         return cat_features_index
